@@ -1,7 +1,7 @@
 package App::rimetadb;
 
-our $DATE = '2016-03-10'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -643,6 +643,48 @@ sub arguments {
     [200, "OK", \@rows, {'table.fields'=>\@columns}];
 }
 
+$SPEC{meta} = {
+    v => 1.1,
+    summary => 'Get package/function metadata',
+    args => {
+        %args_common,
+        name => {
+            summary => '(Fully-qualified) function name or package name',
+            schema => ['perl::modname'],
+            req => 1,
+            pos => 0,
+        },
+    },
+};
+sub meta {
+    my %args = @_;
+
+    my ($res, $dbh) = _connect_db(\%args);
+    return $res unless $res->[0] == 200;
+
+    my $name = $args{name};
+
+    # try function metadata first
+    {
+        my ($package, $func) = $name =~ /(.+)::(.+)/
+            or last;
+
+        my ($row) = $dbh->selectrow_hashref(
+            "SELECT metadata FROM function WHERE package=? AND name=?", {},
+            $package, $func)
+            or last;
+
+        return [200, "OK (func meta)", $row->{metadata}];
+    }
+
+    # try package metadata
+    my ($row) = $dbh->selectrow_hashref(
+        "SELECT metadata FROM package WHERE name=?", {}, $name)
+        or return [404, "Can't find function or package with that name"];
+
+    [200, "OK (package meta)", $row->{metadata}];
+}
+
 1;
 # ABSTRACT: Manage a Rinci metadata database
 
@@ -658,7 +700,7 @@ App::rimetadb - Manage a Rinci metadata database
 
 =head1 VERSION
 
-This document describes version 0.16 of App::rimetadb (from Perl distribution App-rimetadb), released on 2016-03-10.
+This document describes version 0.17 of App::rimetadb (from Perl distribution App-rimetadb), released on 2016-09-27.
 
 =head1 SYNOPSIS
 
@@ -800,6 +842,51 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 meta(%args) -> [status, msg, result, meta]
+
+Get package/function metadata.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<dsn> => I<str>
+
+DBI connection DSN.
+
+If not specified, will default to C<dbd:SQLite:$HOME/rimeta.db> where C<$HOME> is
+user's home directory.
+
+Note: has been tested with MySQL and SQLite only.
+
+=item * B<name>* => I<perl::modname>
+
+(Fully-qualified) function name or package name.
+
+=item * B<password> => I<str>
+
+DBI connection password.
+
+=item * B<user> => I<str>
+
+DBI connection user.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 packages(%args) -> [status, msg, result, meta]
 
 List packages.
